# `narwhals.Expr.str`

::: narwhals.expression.ExprStringNamespace
    handler: python
    options:
      members:
        - ends_with
        - head
        - to_datetime
      show_source: false
      show_bases: false
